# Print an optspec for argparse to handle cmd's options that are independent of any subcommand.
function __fish_convco_global_optspecs
	string join \n C= c/config= h/help V/version
end

function __fish_convco_needs_command
	# Figure out if the current invocation already has a command.
	set -l cmd (commandline -opc)
	set -e cmd[1]
	argparse -s (__fish_convco_global_optspecs) -- $cmd 2>/dev/null
	or return
	if set -q argv[1]
		# Also print the command, so this can be used to figure out what it is.
		echo $argv[1]
		return 1
	end
	return 0
end

function __fish_convco_using_subcommand
	set -l cmd (__fish_convco_needs_command)
	test -z "$cmd"
	and return 1
	contains -- $cmd[1] $argv
end

complete -c convco -n "__fish_convco_needs_command" -s C -d 'Run as if convco was started in <path> instead of the current working directory' -r -F
complete -c convco -n "__fish_convco_needs_command" -s c -l config -r -F
complete -c convco -n "__fish_convco_needs_command" -s h -l help -d 'Print help'
complete -c convco -n "__fish_convco_needs_command" -s V -l version -d 'Print version'
complete -c convco -n "__fish_convco_needs_command" -f -a "config" -d 'Actions for configuration'
complete -c convco -n "__fish_convco_needs_command" -f -a "check" -d 'Verifies if all commits are conventional'
complete -c convco -n "__fish_convco_needs_command" -f -a "changelog" -d 'Writes out a changelog'
complete -c convco -n "__fish_convco_needs_command" -f -a "version" -d 'Show the current version'
complete -c convco -n "__fish_convco_needs_command" -f -a "commit" -d 'Helps to make conventional commits'
complete -c convco -n "__fish_convco_needs_command" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
complete -c convco -n "__fish_convco_using_subcommand config" -s C -d 'Run as if convco was started in <path> instead of the current working directory' -r -F
complete -c convco -n "__fish_convco_using_subcommand config" -s c -l config -r -F
complete -c convco -n "__fish_convco_using_subcommand config" -s d -l default -d 'Print out the default configuration instead of the current configuration'
complete -c convco -n "__fish_convco_using_subcommand config" -s h -l help -d 'Print help'
complete -c convco -n "__fish_convco_using_subcommand check" -s n -l max-count -d 'Limit the number of commits to check' -r
complete -c convco -n "__fish_convco_using_subcommand check" -s C -d 'Run as if convco was started in <path> instead of the current working directory' -r -F
complete -c convco -n "__fish_convco_using_subcommand check" -s c -l config -r -F
complete -c convco -n "__fish_convco_using_subcommand check" -l merges -d 'Include conventional merge commits (commits with more than 1 parent) in the changelog'
complete -c convco -n "__fish_convco_using_subcommand check" -l first-parent -d 'Follow only the first parent'
complete -c convco -n "__fish_convco_using_subcommand check" -l ignore-reverts -d 'Ignore commits created by `git revert` commands'
complete -c convco -n "__fish_convco_using_subcommand check" -l from-stdin -d 'Read a single commit message from stdin'
complete -c convco -n "__fish_convco_using_subcommand check" -l strip -d 'String comments and whitespace from commit message This is similar to `git commit --cleanup=strip`'
complete -c convco -n "__fish_convco_using_subcommand check" -s h -l help -d 'Print help'
complete -c convco -n "__fish_convco_using_subcommand changelog" -s p -l prefix -d 'Prefix used in front of the semantic version' -r
complete -c convco -n "__fish_convco_using_subcommand changelog" -s m -l max-versions -d 'Limits the number of version tags to add in the changelog' -r
complete -c convco -n "__fish_convco_using_subcommand changelog" -l max-minors -d 'Only print this number of minor versions' -r
complete -c convco -n "__fish_convco_using_subcommand changelog" -l max-majors -d 'Only show this number of major versions' -r
complete -c convco -n "__fish_convco_using_subcommand changelog" -l max-patches -d 'Only show this number of patch versions' -r
complete -c convco -n "__fish_convco_using_subcommand changelog" -s P -l paths -d 'Only commits that update those <paths> will be taken into account. It is useful to support monorepos. Each path should be relative to the root of the repository' -r -F
complete -c convco -n "__fish_convco_using_subcommand changelog" -l line-length -d 'Max line length before wrapping. This only makes sense if the template makes use of `{{#word-wrap}}` blocks' -r
complete -c convco -n "__fish_convco_using_subcommand changelog" -s u -l unreleased -d 'Change the title for the unreleased commits. If a semantic version is given, the title will be prefixed' -r
complete -c convco -n "__fish_convco_using_subcommand changelog" -s o -l output -d 'Path to write the changelog to' -r -F
complete -c convco -n "__fish_convco_using_subcommand changelog" -s C -d 'Run as if convco was started in <path> instead of the current working directory' -r -F
complete -c convco -n "__fish_convco_using_subcommand changelog" -s c -l config -r -F
complete -c convco -n "__fish_convco_using_subcommand changelog" -s s -l skip-empty
complete -c convco -n "__fish_convco_using_subcommand changelog" -l ignore-prereleases -d 'Ignore pre-release versions when finding the last version'
complete -c convco -n "__fish_convco_using_subcommand changelog" -s n -l no-links -d 'Do not generate links. Overrides linkReferences and linkCompare in the config'
complete -c convco -n "__fish_convco_using_subcommand changelog" -l merges -d 'Include conventional merge commits (commits with more than 1 parent) in the changelog'
complete -c convco -n "__fish_convco_using_subcommand changelog" -l include-hidden-sections -d 'Print hidden sections'
complete -c convco -n "__fish_convco_using_subcommand changelog" -l first-parent -d 'Follow only the first parent of merge commits. Commits from the merged branche(s) will be discarded'
complete -c convco -n "__fish_convco_using_subcommand changelog" -l no-wrap -d 'Do not wrap lines. This only makes sense if the template makes use of `{{#word-wrap}}` blocks'
complete -c convco -n "__fish_convco_using_subcommand changelog" -s h -l help -d 'Print help'
complete -c convco -n "__fish_convco_using_subcommand version" -s p -l prefix -d 'Prefix used in front of the semantic version' -r
complete -c convco -n "__fish_convco_using_subcommand version" -l prerelease -d 'Suffix with a prerelease version. Requires --bump' -r
complete -c convco -n "__fish_convco_using_subcommand version" -s P -l paths -d 'Only commits that update those <paths> will be taken into account. It is useful to support monorepos. Each path should be relative to the root of the repository' -r -F
complete -c convco -n "__fish_convco_using_subcommand version" -l initial-bump-version -d 'If no version is found use this version for the first bump' -r
complete -c convco -n "__fish_convco_using_subcommand version" -s C -d 'Run as if convco was started in <path> instead of the current working directory' -r -F
complete -c convco -n "__fish_convco_using_subcommand version" -s c -l config -r -F
complete -c convco -n "__fish_convco_using_subcommand version" -l print-prefix -l pp -d 'Print prefix in front of the semantic version'
complete -c convco -n "__fish_convco_using_subcommand version" -s b -l bump -d 'Get the next version'
complete -c convco -n "__fish_convco_using_subcommand version" -s l -l label -d 'Instead of printing out the bumped version, prints out one of: major, minor or patch'
complete -c convco -n "__fish_convco_using_subcommand version" -l major -d 'Bump to a major release version, regardless of the conventional commits'
complete -c convco -n "__fish_convco_using_subcommand version" -l minor -d 'Bump to a minor release version, regardless of the conventional commits'
complete -c convco -n "__fish_convco_using_subcommand version" -l patch -d 'Bump to a patch release version, regardless of the conventional commits'
complete -c convco -n "__fish_convco_using_subcommand version" -l commit-sha -d 'Print the commit-sha of the version instead of the semantic version'
complete -c convco -n "__fish_convco_using_subcommand version" -l ignore-prereleases -d 'Ignore pre-release versions when finding the last version'
complete -c convco -n "__fish_convco_using_subcommand version" -s h -l help -d 'Print help'
complete -c convco -n "__fish_convco_using_subcommand commit" -s t -l type -d 'Specify your own commit type' -r
complete -c convco -n "__fish_convco_using_subcommand commit" -s s -l scope -d 'Specifies the scope of the message' -r
complete -c convco -n "__fish_convco_using_subcommand commit" -s m -l message -d 'The first message will be the description. Other -m options will be used as the body' -r
complete -c convco -n "__fish_convco_using_subcommand commit" -s f -l footers -l trailer -d 'Specify extra footers to the message' -r
complete -c convco -n "__fish_convco_using_subcommand commit" -s N -l intent-to-add -d 'Runs `git add -N <PATH>`. An entry for the path is placed in the index with no content. This is useful in combination with --patch' -r -F
complete -c convco -n "__fish_convco_using_subcommand commit" -s C -d 'Run as if convco was started in <path> instead of the current working directory' -r -F
complete -c convco -n "__fish_convco_using_subcommand commit" -s c -l config -r -F
complete -c convco -n "__fish_convco_using_subcommand commit" -l fix -d 'A bug fix'
complete -c convco -n "__fish_convco_using_subcommand commit" -l feat -d 'A new feature'
complete -c convco -n "__fish_convco_using_subcommand commit" -l build -d 'Changes that affect the build system or external dependencies'
complete -c convco -n "__fish_convco_using_subcommand commit" -l chore -d 'Other changes that don\'t modify src or test files'
complete -c convco -n "__fish_convco_using_subcommand commit" -l ci -d 'Changes to CI configuration files and scripts'
complete -c convco -n "__fish_convco_using_subcommand commit" -l docs -d 'Documentation only changes'
complete -c convco -n "__fish_convco_using_subcommand commit" -l style -d 'Changes that do not affect the meaning of the code (e.g. formatting)'
complete -c convco -n "__fish_convco_using_subcommand commit" -l refactor -d 'A code change that neither fixes a bug nor adds a feature'
complete -c convco -n "__fish_convco_using_subcommand commit" -l perf -d 'A code change that improves performance'
complete -c convco -n "__fish_convco_using_subcommand commit" -l test -d 'Adding missing tests or correcting existing tests'
complete -c convco -n "__fish_convco_using_subcommand commit" -l breaking -d 'Introduces a breaking change'
complete -c convco -n "__fish_convco_using_subcommand commit" -s i -l interactive -d 'Interactive mode. Start the wizard if no type and description is given'
complete -c convco -n "__fish_convco_using_subcommand commit" -s p -l patch -d 'Runs `git add -p`. Interactively choose hunks of patch between the index and the work tree'
complete -c convco -n "__fish_convco_using_subcommand commit" -s h -l help -d 'Print help'
complete -c convco -n "__fish_convco_using_subcommand help; and not __fish_seen_subcommand_from config check changelog version commit help" -f -a "config" -d 'Actions for configuration'
complete -c convco -n "__fish_convco_using_subcommand help; and not __fish_seen_subcommand_from config check changelog version commit help" -f -a "check" -d 'Verifies if all commits are conventional'
complete -c convco -n "__fish_convco_using_subcommand help; and not __fish_seen_subcommand_from config check changelog version commit help" -f -a "changelog" -d 'Writes out a changelog'
complete -c convco -n "__fish_convco_using_subcommand help; and not __fish_seen_subcommand_from config check changelog version commit help" -f -a "version" -d 'Show the current version'
complete -c convco -n "__fish_convco_using_subcommand help; and not __fish_seen_subcommand_from config check changelog version commit help" -f -a "commit" -d 'Helps to make conventional commits'
complete -c convco -n "__fish_convco_using_subcommand help; and not __fish_seen_subcommand_from config check changelog version commit help" -f -a "help" -d 'Print this message or the help of the given subcommand(s)'
